pystagram.graph_api.components.breakdown package — pystagram 0.1 documentation

# pystagram.graph_api.components.breakdown package

## Submodules

## pystagram.graph_api.components.breakdown.breakdown module

class pystagram.graph_api.components.breakdown.breakdown.Breakdown(value)

  Bases: `str`, `Enum`

  Designates how to break down a result set into subsets.

  ACTION_TYPE = 'action_type'
  STORY_NAVIGATION_ACTION_TYPE = 'story_navigation_action_type'

## Module contents